# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opus_protobuf/web.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17opus_protobuf/web.proto\x12\x03web\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1aopus_protobuf/common.proto\"\x16\n\x07\x43svFile\x12\x0b\n\x03url\x18\x01 \x01(\t\"\xca\x01\n\x04User\x12\x11\n\tfirstName\x18\x01 \x01(\t\x12\x15\n\x08lastName\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x05 \x01(\t\x12\x10\n\x08\x62irthday\x18\x06 \x01(\t\x12\x0e\n\x06tenant\x18\x07 \x01(\t\x12\x10\n\x08industry\x18\x08 \x01(\t\x12\x17\n\x0findustrySegment\x18\t \x01(\t\x12\x0c\n\x04tags\x18\n \x01(\tB\x0b\n\t_lastName\" \n\x05Users\x12\x17\n\x04user\x18\x01 \x03(\x0b\x32\t.web.User2q\n\rWebController\x12\x37\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x0e.common.Health\"\x00\x12\'\n\tCsvToJson\x12\x0c.web.CsvFile\x1a\n.web.Users\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opus_protobuf.web_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CSVFILE']._serialized_start=89
  _globals['_CSVFILE']._serialized_end=111
  _globals['_USER']._serialized_start=114
  _globals['_USER']._serialized_end=316
  _globals['_USERS']._serialized_start=318
  _globals['_USERS']._serialized_end=350
  _globals['_WEBCONTROLLER']._serialized_start=352
  _globals['_WEBCONTROLLER']._serialized_end=465
# @@protoc_insertion_point(module_scope)
